package kaka.cakelight;

import kaka.cakelight.mode.AmbientMode;
import kaka.cakelight.mode.SingleColorMode;
import kaka.cakelight.mode.VideoMode;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

public class Console extends Thread {
    private CakeLight cakelight;
    private Configuration config;
    private BufferedReader reader;

    public static void start(CakeLight cakelight, Configuration config) {
        new Console(cakelight, config).start();
    }

    private Console(CakeLight cakelight, Configuration config) {
        this.cakelight = cakelight;
	this.config = config;
	reader = new BufferedReader(new InputStreamReader(System.in));
    }

    @Override
    public void run() {
        while (true) {
            System.out.print("> ");
            try {
                String input = reader.readLine();
                if (input.matches("[0-5]")) {
		    cakelight.setMode(new AmbientMode(new String[] {input}));
		    System.out.println("setting ambient mode to " + input);
		} else if (input.matches("v|video")) {
                    cakelight.setMode(new VideoMode());
		} else if (input.matches("(b|brightness)\\s+[0-9]+")) {
		    String[] split = input.split("\\s+");
		    config.leds.brightness = Integer.parseInt(split[1]);
		    System.out.println("setting brightness to " + config.leds.brightness);
		} else if (input.matches("q|quit")) {
		    cakelight.turnOff();
		    System.out.println("stopping cakelight");
		    break;
		} else if (input.matches("(c|col|color)(\\s+[0-9]+){3}")) {
		    String[] split = input.split("\\s+");
		    Color c = Color.rgb(
			    Integer.parseInt(split[1]),
			    Integer.parseInt(split[2]),
			    Integer.parseInt(split[3])
		    );
		    cakelight.setMode(new SingleColorMode(c));
		    System.out.println("setting color to " + c);
		} else if (input.matches("(g|gamma)\\s+[0-9.]+")) {
		    String[] split = input.split("\\s+");
		    config.gamma = Double.parseDouble(split[1]);
		    Color.calculateGammaCorrection(config.gamma);
		    System.out.println("setting gamma to " + config.gamma);
		} else if (input.matches("(s|saturation)\\s+[0-9.]+")) {
		    String[] split = input.split("\\s+");
		    config.video.saturation = Double.parseDouble(split[1]);
		    System.out.println("setting saturation to " + config.video.saturation);
		}
            } catch (IOException e) {
                System.out.println("Error reading from command line");
                break;
            }
        }
    }
}
